@@ -22,525 +22,531 @@ namespace mozilla {
 namespace xpcom {
 
 enum class ModuleID : uint16_t {
-  Anonymous359,
-  Anonymous213,
-  Anonymous220,
+  Anonymous270,
+  Anonymous062,
+  Anonymous184,
+  Anonymous099,
+  Anonymous044,
+  Anonymous226,
+  Anonymous253,
+  Anonymous339,
+  Preferences,
+  Anonymous058,
+  Anonymous234,
+  Anonymous428,
+  Anonymous041,
+  Anonymous019,
+  Anonymous264,
+  Anonymous306,
+  Anonymous390,
+  Anonymous199,
+  Anonymous356,
+  Anonymous167,
+  Anonymous447,
+  Anonymous441,
+  Anonymous020,
+  CaptivePortal,
+  Anonymous393,
+  Anonymous153,
+  Anonymous348,
+  UUIDGenerator,
+  Anonymous260,
+  Anonymous109,
+  Anonymous261,
+  Anonymous239,
+  Anonymous319,
+  Anonymous016,
+  Anonymous063,
+  Anonymous365,
+  Anonymous341,
+  Anonymous387,
+  Anonymous352,
+  Anonymous255,
+  Anonymous287,
+  Anonymous240,
+  Anonymous446,
+  Anonymous140,
+  Anonymous242,
+  Anonymous147,
+  Anonymous010,
+  Anonymous068,
   Anonymous142,
+  Anonymous036,
+  ExternalProtocolHandler,
+  Anonymous413,
+  Anonymous375,
+  Dashboard,
+  Anonymous401,
+  Anonymous079,
+  WifiMonitor,
+  Anonymous228,
+  Anonymous332,
+  Anonymous353,
+  Anonymous254,
+  Anonymous200,
+  Anonymous355,
+  Anonymous120,
+  Anonymous108,
+  StringBundle,
+  Anonymous402,
+  Anonymous024,
+  nsIContentAnalysis,
+  Anonymous214,
+  ThirdPartyUtil,
+  Anonymous278,
+  Anonymous334,
+  Anonymous131,
+  Anonymous338,
+  Anonymous429,
+  Anonymous379,
+  Anonymous055,
+  Anonymous148,
+  Anonymous181,
+  Anonymous135,
+  Anonymous192,
+  Anonymous129,
+  HttpHandler,
+  CredentialChooserService,
+  Anonymous064,
+  Anonymous033,
+  Anonymous384,
+  Anonymous021,
+  Anonymous290,
+  Anonymous415,
+  Anonymous386,
+  Anonymous305,
+  Anonymous066,
+  Anonymous137,
+  Anonymous335,
+  Anonymous215,
+  NSSCertificateDB,
+  Anonymous103,
+  PlacesPreviewsHelper,
+  Anonymous366,
+  Anonymous216,
+  Anonymous426,
+  Anonymous247,
+  CORSPreflightCache,
+  Anonymous122,
+  Anonymous296,
+  Anonymous031,
+  Anonymous197,
+  Anonymous141,
+  Anonymous054,
+  Anonymous032,
+  Anonymous347,
+  Anonymous302,
+  CookieBannerService,
+  WindowWatcher,
+  Anonymous288,
+  GfxInfo,
+  Anonymous102,
+  Anonymous258,
+  MimeHeaderParam,
+  Anonymous385,
   URILoader,
+  Anonymous323,
+  Anonymous080,
+  Anonymous098,
+  Anonymous397,
+  Anonymous143,
+  RFPService,
+  Anonymous086,
+  Anonymous436,
+  Anonymous310,
+  URIFixup,
+  Anonymous280,
+  Predictor,
+  Anonymous190,
+  Anonymous144,
+  Anonymous391,
+  Anonymous262,
+  Anonymous050,
+  Anonymous444,
+  Anonymous327,
+  UrlClassifierUtils,
+  Anonymous012,
+  Anonymous185,
+  Anonymous130,
+  Anonymous313,
+  Anonymous045,
+  Anonymous378,
+  Anonymous238,
+  SystemInfo,
+  Anonymous174,
+  Anonymous372,
+  Anonymous172,
+  HttpActivityDistributor,
+  Anonymous359,
+  Anonymous078,
+  Anonymous151,
+  Anonymous371,
+  Anonymous211,
+  Anonymous049,
+  Anonymous097,
+  Anonymous011,
+  Anonymous128,
+  Anonymous118,
+  FileProtocolHandler,
+  Anonymous389,
+  Anonymous048,
+  Anonymous117,
+  Anonymous249,
+  Anonymous227,
+  Anonymous125,
+  Anonymous295,
+  Anonymous273,
+  Anonymous374,
+  Anonymous414,
+  ChromeRegistry,
+  Anonymous203,
+  Anonymous040,
+  Anonymous149,
+  Anonymous035,
+  DNS,
+  Anonymous003,
+  Anonymous069,
+  Anonymous392,
+  Anonymous408,
+  Anonymous362,
+  Anonymous311,
+  DocLoader,
+  RandomGenerator,
+  Anonymous180,
+  Anonymous354,
+  Anonymous245,
+  Anonymous152,
+  Anonymous267,
+  Anonymous005,
+  Anonymous442,
+  EffectiveTLD,
+  Anonymous388,
+  Anonymous134,
+  Anonymous274,
+  UrlClassifierPrefixSet,
+  Anonymous320,
+  Anonymous029,
+  Anonymous107,
+  Anonymous171,
+  Anonymous286,
+  Anonymous084,
+  Anonymous417,
+  Anonymous081,
+  Anonymous001,
+  Anonymous395,
+  Anonymous090,
+  NSSComponent,
+  NSSErrors,
+  Anonymous073,
+  AsyncShutdown,
+  Anonymous357,
+  Anonymous170,
+  Anonymous405,
+  Anonymous165,
+  Anonymous023,
+  Anonymous101,
+  NetworkErrorLogging,
+  AddonContentPolicy,
+  Anonymous150,
+  Anonymous346,
+  Anonymous155,
+  Anonymous244,
+  Anonymous303,
+  Anonymous246,
+  AppStartup,
+  Anonymous271,
+  Anonymous422,
+  Anonymous191,
+  Anonymous410,
+  Anonymous189,
+  Anonymous067,
+  Anonymous223,
+  Anonymous047,
+  Anonymous281,
+  Alerts,
+  ApplicationReputation,
+  Anonymous330,
+  Anonymous113,
+  Anonymous208,
+  Anonymous314,
+  Locale,
+  Anonymous293,
+  Observer,
   Anonymous272,
   Anonymous119,
-  Anonymous029,
-  Anonymous319,
-  Anonymous369,
-  Anonymous395,
-  Anonymous253,
-  Anonymous249,
-  Anonymous136,
-  Anonymous259,
-  Anonymous123,
-  Anonymous430,
-  Anonymous046,
-  Anonymous428,
-  Anonymous422,
-  Anonymous440,
-  Anonymous051,
-  Anonymous016,
-  Anonymous177,
-  Anonymous408,
-  StreamConverter,
-  Anonymous264,
-  CORSPreflightCache,
-  Anonymous009,
-  CategoryManager,
-  Anonymous083,
-  Anonymous073,
-  Anonymous174,
-  Anonymous333,
-  Anonymous092,
-  Anonymous387,
-  Anonymous299,
-  ScriptSecurityManager,
-  Anonymous195,
-  Anonymous231,
-  Anonymous417,
-  Anonymous088,
-  Anonymous011,
-  BounceTrackingProtection,
-  Anonymous281,
-  Anonymous114,
-  Anonymous411,
-  Anonymous380,
-  Anonymous169,
-  NSSErrors,
-  StringBundle,
-  Anonymous241,
-  Observer,
-  Anonymous219,
-  Anonymous108,
-  Anonymous205,
-  Anonymous339,
-  Anonymous067,
-  HttpActivityDistributor,
-  Anonymous032,
-  Anonymous262,
-  Anonymous054,
-  CaptivePortal,
-  Anonymous401,
-  Anonymous154,
-  Anonymous206,
-  Anonymous019,
-  Anonymous410,
-  AddonContentPolicy,
-  Directory,
-  Anonymous137,
-  Anonymous121,
-  Anonymous348,
-  Anonymous162,
-  Anonymous025,
-  Anonymous216,
-  Anonymous057,
-  Anonymous321,
-  Anonymous047,
-  Anonymous302,
-  Anonymous026,
-  Anonymous305,
-  Anonymous442,
-  Anonymous132,
-  ChromeRegistry,
-  Anonymous099,
-  Anonymous224,
-  Anonymous399,
-  Anonymous081,
-  Anonymous248,
-  Anonymous192,
-  Anonymous061,
-  Anonymous116,
-  Anonymous265,
-  Anonymous412,
-  Anonymous087,
-  Anonymous371,
-  DBusHandlerApp,
-  Anonymous202,
-  Anonymous396,
-  Anonymous247,
-  Anonymous135,
-  Anonymous297,
-  Anonymous015,
-  Anonymous343,
-  Anonymous407,
-  UUIDGenerator,
-  Anonymous358,
-  Anonymous403,
-  Anonymous090,
-  Anonymous107,
-  Anonymous344,
-  Anonymous300,
-  Anonymous373,
-  IDN,
-  Anonymous150,
-  Anonymous374,
-  Anonymous084,
-  Anonymous199,
-  Anonymous432,
-  Anonymous066,
-  Anonymous172,
-  Anonymous182,
-  Anonymous258,
-  Anonymous149,
-  History,
-  Anonymous117,
-  Anonymous323,
-  Anonymous164,
-  Anonymous040,
-  Anonymous144,
-  Anonymous056,
-  Anonymous379,
-  Anonymous364,
-  Preferences,
-  Anonymous063,
-  Anonymous152,
-  Anonymous157,
-  ProtocolProxy,
-  Anonymous004,
-  Anonymous287,
-  Anonymous235,
-  Anonymous233,
-  Anonymous278,
-  Anonymous183,
-  Anonymous112,
-  Anonymous022,
-  Anonymous209,
-  Anonymous062,
-  Anonymous124,
-  Anonymous329,
-  Anonymous037,
-  Anonymous336,
-  Anonymous194,
-  Anonymous179,
-  Anonymous237,
-  Anonymous423,
-  Anonymous327,
-  Anonymous429,
-  Anonymous147,
-  Anonymous433,
-  Anonymous274,
-  Anonymous221,
-  Anonymous155,
-  Anonymous109,
-  Anonymous165,
-  Anonymous161,
-  Anonymous227,
-  Anonymous236,
-  Anonymous082,
-  MimeHeaderParam,
-  URLQueryStringStripper,
-  Anonymous341,
-  Anonymous397,
-  IdentityCredentialStorageService,
-  Anonymous386,
-  Anonymous361,
-  URIFixup,
-  Anonymous234,
-  Anonymous048,
-  Anonymous044,
-  Anonymous129,
-  Anonymous006,
-  NetworkErrorLogging,
-  Anonymous431,
-  Anonymous096,
-  Anonymous001,
-  Anonymous065,
-  Anonymous053,
-  Anonymous208,
-  Anonymous003,
-  CredentialChooserService,
-  Anonymous212,
-  Anonymous279,
-  Anonymous254,
-  Anonymous384,
-  Anonymous060,
-  Anonymous168,
-  Anonymous189,
-  Anonymous049,
-  Anonymous176,
-  Anonymous143,
-  Alerts,
-  Anonymous290,
-  Anonymous187,
-  Anonymous043,
-  Anonymous215,
-  Anonymous436,
-  Anonymous052,
-  UrlClassifierStreamUpdater,
-  Anonymous340,
-  Anonymous128,
-  Anonymous245,
-  Anonymous294,
-  Anonymous218,
-  Anonymous008,
-  Anonymous193,
-  XULRuntime,
-  Anonymous261,
-  Anonymous392,
-  Anonymous356,
-  Anonymous335,
-  Anonymous093,
-  Anonymous217,
-  Anonymous315,
-  CacheStorage,
-  Anonymous317,
-  Anonymous390,
+  Anonymous298,
   Anonymous283,
-  Anonymous035,
-  Anonymous288,
-  Anonymous010,
-  Anonymous078,
-  Anonymous324,
-  AppStartup,
-  Anonymous140,
-  IO,
-  Anonymous376,
-  Anonymous111,
-  Anonymous191,
-  FindService,
-  Anonymous184,
-  ContentSecurityManager,
-  Anonymous251,
-  PrivateAttribution,
-  Anonymous211,
-  Anonymous286,
-  Anonymous268,
-  Anonymous372,
-  Anonymous106,
-  Anonymous406,
-  AlertNotification,
-  EffectiveTLD,
-  Anonymous352,
-  TypeAheadFind,
-  Anonymous171,
-  Anonymous424,
-  Anonymous439,
+  Anonymous195,
+  Anonymous037,
+  Anonymous127,
+  Anonymous201,
+  Anonymous092,
+  Anonymous285,
   Anonymous316,
-  Anonymous255,
-  Anonymous354,
-  WindowWatcher,
-  Anonymous086,
-  Anonymous437,
-  Anonymous225,
-  Anonymous320,
-  Anonymous250,
-  Anonymous256,
-  Anonymous141,
-  Anonymous312,
-  Anonymous210,
-  Anonymous115,
-  Anonymous349,
-  RFPService,
-  Anonymous138,
-  Prefetch,
-  Anonymous419,
-  Anonymous328,
-  Anonymous277,
-  Anonymous103,
-  Anonymous413,
-  Anonymous228,
-  Anonymous226,
-  Anonymous072,
-  Anonymous282,
-  Anonymous338,
-  Anonymous167,
-  Anonymous242,
-  Anonymous095,
-  IdentityCredentialPromptService,
-  Anonymous163,
+  Anonymous416,
   Anonymous100,
-  Anonymous322,
-  Anonymous070,
-  Anonymous021,
-  Anonymous414,
-  Anonymous075,
-  AsyncShutdown,
-  TextToSubURI,
-  Console,
-  Anonymous064,
-  HttpHandler,
-  Anonymous230,
-  Anonymous375,
-  ApplicationReputation,
-  Anonymous366,
-  Anonymous069,
-  Anonymous275,
-  Anonymous405,
-  Anonymous034,
-  Anonymous188,
-  Anonymous346,
-  Anonymous400,
-  nsIContentAnalysis,
-  DocLoader,
-  Anonymous091,
-  Anonymous041,
-  Anonymous020,
-  Anonymous156,
-  Anonymous012,
-  Anonymous363,
-  Anonymous266,
-  Anonymous355,
-  Anonymous045,
-  Anonymous276,
-  Anonymous263,
-  Anonymous113,
-  Anonymous042,
-  SocketTransport,
-  Anonymous160,
-  NSSComponent,
-  Anonymous238,
-  Anonymous402,
-  ExtensionPolicy,
-  Anonymous271,
-  Anonymous028,
-  Anonymous145,
-  Anonymous360,
+  Anonymous110,
+  Anonymous368,
+  Anonymous173,
+  Anonymous017,
+  IdentityCredentialPromptService,
+  Anonymous259,
+  Anonymous030,
+  DownloadPlatform,
+  Anonymous317,
+  Anonymous159,
+  Anonymous209,
+  Anonymous324,
+  Anonymous166,
+  Anonymous315,
+  Anonymous157,
+  Anonymous243,
+  Anonymous133,
+  StreamConverter,
+  Anonymous309,
+  ContentSecurityManager,
+  Anonymous220,
+  Anonymous083,
   Anonymous039,
-  PermissionManager,
-  Anonymous307,
-  Anonymous383,
-  Anonymous148,
-  Anonymous079,
-  Anonymous289,
-  Anonymous311,
-  Anonymous388,
-  Anonymous170,
-  CookieBannerService,
-  Anonymous326,
   Anonymous196,
-  Anonymous214,
-  Anonymous080,
+  Anonymous007,
+  PageThumbsStorage,
+  Anonymous248,
+  Anonymous082,
+  Anonymous312,
+  Anonymous015,
+  Anonymous182,
   Anonymous345,
-  Anonymous104,
-  Anonymous385,
-  Anonymous427,
-  Anonymous441,
-  UrlClassifierDB,
+  Anonymous042,
+  Anonymous206,
+  Anonymous213,
+  Anonymous291,
+  Anonymous265,
+  Anonymous370,
+  Anonymous318,
+  Anonymous169,
+  FindService,
+  Anonymous018,
+  Anonymous161,
+  Anonymous307,
+  Anonymous075,
+  Anonymous400,
+  Anonymous420,
+  Anonymous221,
+  Anonymous014,
+  Anonymous403,
+  Anonymous423,
+  Anonymous373,
+  Anonymous111,
+  Anonymous325,
+  XULRuntime,
+  Anonymous369,
+  Anonymous106,
+  Anonymous294,
+  Anonymous198,
+  Anonymous162,
+  Anonymous210,
+  Anonymous156,
+  Anonymous072,
+  Anonymous158,
+  Anonymous126,
+  Anonymous421,
+  Anonymous322,
+  TypeAheadFind,
+  Anonymous091,
+  Anonymous112,
+  Anonymous057,
+  Anonymous289,
+  Anonymous282,
+  Anonymous232,
+  Anonymous193,
+  Anonymous121,
+  URLQueryStringStripper,
+  Anonymous266,
+  Anonymous432,
+  Anonymous070,
   Anonymous350,
-  DNS,
-  NSSCertificateDB,
+  Anonymous124,
+  Anonymous367,
+  Anonymous094,
+  Anonymous399,
+  Anonymous351,
+  Anonymous179,
+  Anonymous061,
+  PermissionManager,
+  Anonymous336,
+  Anonymous427,
+  Anonymous145,
+  PrivateAttribution,
+  Anonymous188,
+  Anonymous363,
+  Anonymous233,
+  Anonymous252,
+  Anonymous123,
+  Anonymous409,
+  Anonymous060,
+  Anonymous025,
+  Anonymous114,
+  Anonymous439,
+  IdentityCredentialStorageService,
+  Anonymous342,
+  Anonymous009,
+  Anonymous443,
+  Anonymous164,
+  Anonymous284,
+  Anonymous212,
+  Anonymous089,
   Anonymous002,
-  Anonymous122,
+  Anonymous411,
+  Anonymous438,
+  Anonymous093,
+  Anonymous022,
+  Anonymous008,
+  Anonymous034,
+  Anonymous013,
+  Anonymous419,
+  Anonymous027,
+  Anonymous186,
+  Console,
+  UrlClassifierTestUtils,
+  Anonymous445,
+  Anonymous229,
+  Anonymous407,
+  Anonymous026,
+  Anonymous434,
+  Anonymous344,
+  ExtensionPolicy,
+  CategoryManager,
+  Anonymous321,
+  Anonymous275,
+  TextToSubURI,
+  Anonymous380,
+  Anonymous263,
+  Anonymous256,
+  Anonymous430,
+  Anonymous163,
+  UrlClassifierDB,
+  Anonymous331,
+  Anonymous431,
+  Anonymous297,
+  Anonymous218,
+  Anonymous361,
+  Anonymous051,
+  Anonymous326,
+  Anonymous043,
+  Anonymous383,
+  Anonymous277,
+  Anonymous207,
+  Anonymous328,
+  Anonymous300,
+  Anonymous004,
+  Anonymous132,
+  Anonymous224,
+  Directory,
+  Anonymous268,
+  Anonymous231,
+  Anonymous425,
+  AuthPromptAdapter,
+  Anonymous205,
+  Anonymous440,
+  Anonymous138,
+  Anonymous376,
+  CacheStorage,
+  Anonymous398,
+  Anonymous381,
+  Anonymous340,
+  AlertNotification,
+  Anonymous176,
+  Anonymous028,
+  Anonymous424,
+  Anonymous250,
+  Anonymous237,
+  Anonymous257,
+  BounceTrackingProtection,
+  Anonymous360,
+  Anonymous077,
   Anonymous404,
   Anonymous377,
-  DownloadPlatform,
-  Anonymous298,
-  Anonymous200,
-  Anonymous368,
-  Anonymous292,
-  Anonymous270,
-  ServiceWorkerManager,
-  Anonymous280,
-  Anonymous332,
-  UrlClassifierPrefixSet,
-  Anonymous201,
-  Anonymous000,
-  Anonymous389,
-  Anonymous331,
-  Anonymous125,
-  Anonymous085,
-  Anonymous014,
-  Predictor,
-  Anonymous102,
-  Anonymous273,
-  Anonymous186,
-  Anonymous257,
-  UrlClassifierUtils,
-  PlacesPreviewsHelper,
-  Anonymous293,
-  Anonymous367,
-  StreamTransport,
-  Anonymous260,
-  Anonymous334,
-  SystemInfo,
-  Anonymous415,
-  Anonymous398,
-  Anonymous378,
-  Anonymous139,
-  Anonymous229,
-  Anonymous005,
-  Anonymous033,
-  Anonymous068,
-  Anonymous204,
-  Anonymous426,
-  Anonymous076,
-  Anonymous118,
-  Anonymous198,
-  Anonymous313,
-  Dashboard,
-  Anonymous074,
-  Anonymous409,
-  Anonymous094,
-  Anonymous013,
-  Anonymous131,
-  Anonymous098,
-  Anonymous438,
-  Anonymous151,
-  Anonymous296,
-  Anonymous434,
-  Anonymous351,
-  Anonymous309,
-  Anonymous370,
-  PageThumbsStorage,
+  DBusHandlerApp,
+  Anonymous053,
+  Anonymous096,
+  ScriptSecurityManager,
   Anonymous146,
-  Anonymous421,
-  Anonymous024,
-  Anonymous240,
-  Anonymous304,
-  Anonymous207,
-  Anonymous030,
-  Anonymous097,
-  Anonymous175,
-  Anonymous308,
-  Anonymous031,
-  Anonymous153,
-  Anonymous330,
-  AuthPromptAdapter,
-  Anonymous365,
-  Anonymous303,
-  Anonymous394,
-  ThirdPartyUtil,
-  Anonymous017,
-  Anonymous362,
-  Anonymous181,
-  GfxInfo,
-  Anonymous036,
-  Anonymous055,
-  Anonymous133,
-  FileProtocolHandler,
-  Anonymous435,
-  Anonymous391,
-  Anonymous244,
-  Anonymous190,
-  Anonymous158,
-  ExternalProtocolHandler,
-  Anonymous101,
-  RandomGenerator,
-  Anonymous203,
-  Anonymous301,
-  Anonymous089,
-  Anonymous134,
-  Anonymous071,
-  Anonymous126,
-  Anonymous347,
-  Anonymous159,
-  SiteSecurity,
-  Anonymous222,
-  Anonymous381,
-  Anonymous267,
-  Anonymous185,
-  Anonymous059,
-  Anonymous166,
-  Locale,
-  Anonymous243,
-  Anonymous310,
-  Anonymous050,
-  Anonymous197,
-  Anonymous023,
-  Anonymous393,
-  Anonymous077,
-  Anonymous295,
-  Anonymous353,
-  Anonymous306,
-  Anonymous318,
-  Anonymous420,
-  Anonymous314,
-  Anonymous357,
+  Anonymous115,
+  Anonymous177,
+  Anonymous349,
+  Anonymous136,
+  Anonymous046,
   Anonymous269,
-  Anonymous180,
-  Anonymous038,
-  Anonymous130,
-  Anonymous178,
-  Anonymous252,
-  Anonymous120,
-  Anonymous173,
-  Anonymous425,
-  Anonymous027,
-  Anonymous110,
-  Anonymous058,
-  Anonymous018,
-  Anonymous342,
-  Anonymous325,
-  Anonymous127,
-  Anonymous285,
-  Anonymous291,
-  Anonymous239,
-  Anonymous007,
-  WifiMonitor,
-  Anonymous418,
-  Anonymous382,
-  Anonymous232,
+  Anonymous394,
+  Anonymous175,
+  IDN,
+  History,
+  SocketTransport,
+  StreamTransport,
+  Anonymous230,
+  Anonymous364,
+  Anonymous183,
   Anonymous105,
-  Anonymous223,
-  Anonymous284,
-  Anonymous416,
-  Anonymous246,
+  Anonymous088,
+  Anonymous095,
+  Anonymous433,
+  Anonymous104,
+  Anonymous292,
+  Anonymous279,
+  Anonymous178,
+  Anonymous074,
+  Anonymous343,
+  Anonymous241,
+  Anonymous065,
+  Anonymous154,
+  Anonymous202,
+  Anonymous276,
+  Anonymous382,
+  Anonymous204,
+  Anonymous437,
+  Anonymous412,
+  Anonymous251,
+  Anonymous358,
+  Anonymous056,
+  Anonymous396,
+  Anonymous168,
+  Anonymous052,
+  Anonymous329,
+  Anonymous187,
+  Anonymous087,
+  IO,
+  Anonymous222,
   Anonymous337,
+  Anonymous225,
+  Anonymous418,
+  Anonymous219,
+  Anonymous038,
+  SiteSecurity,
+  Anonymous304,
+  Anonymous071,
+  Anonymous235,
+  Anonymous301,
+  Anonymous333,
+  Anonymous308,
+  Anonymous217,
+  Anonymous006,
+  Anonymous299,
+  Anonymous236,
+  Prefetch,
+  ServiceWorkerManager,
+  Anonymous076,
+  Anonymous435,
+  Anonymous160,
+  Anonymous139,
+  Anonymous194,
+  Anonymous116,
+  Anonymous085,
+  Anonymous406,
+  Anonymous000,
+  ProtocolProxy,
+  Anonymous059,
+  UrlClassifierStreamUpdater,
 
 };
 
@@ -1480,6 +1486,20 @@ static inline ::mozilla::xpcom::CreateInstanceHelper Create(nsresult* aRv = null
 }
 }  // namespace UrlClassifierStreamUpdater
 
+namespace UrlClassifierTestUtils {
+static inline const nsID& CID() {
+  return ::mozilla::xpcom::Components::GetCID(::mozilla::xpcom::ModuleID::UrlClassifierTestUtils);
+}
+
+static inline ::mozilla::xpcom::GetServiceHelper Service(nsresult* aRv = nullptr) {
+  return {::mozilla::xpcom::ModuleID::UrlClassifierTestUtils, aRv};
+}
+
+static inline ::mozilla::xpcom::CreateInstanceHelper Create(nsresult* aRv = nullptr) {
+  return {::mozilla::xpcom::ModuleID::UrlClassifierTestUtils, aRv};
+}
+}  // namespace UrlClassifierTestUtils
+
 namespace UrlClassifierUtils {
 static inline const nsID& CID() {
   return ::mozilla::xpcom::Components::GetCID(::mozilla::xpcom::ModuleID::UrlClassifierUtils);
